What is SuperPyLib?

SuperPyLib is a Python package for calculating 2-D integral and finite element numerical solutions for Poisson equation with non-overlapping shapes in the presence of Superconducting materials. Import module corrections.

Dependencies:

Python 3.8+, Numpy 1.23.1, Joblib 1.1.0, Matplotlib 3.5.2, and Scipy 1.8.1

Version:

SuperPyLib 0.0.3
